Block device ioctls: BLKGETSIZE64, BLKDISCARD
Standard Linux block device ioctls that are not btrfs-specific but are needed for device preparation (e.g. querying device size, issuing TRIM).
Functions
- blk_
discard ⚠ - blk_
getsize64 ⚠ - device_
size - Get the size of a block device in bytes.
- discard_
range - Issue a BLKDISCARD (TRIM) on the given byte range of a block device.
- discard_
whole_ device - Issue a BLKDISCARD on the entire block device.