Module dev_extent

Module dev_extent 

Device extent tree: per-device physical extent layout

Walks the device tree (BTRFS_DEV_TREE_OBJECTID) to enumerate BTRFS_DEV_EXTENT_KEY items for a given device, then computes the minimum size to which the device can be shrunk.

Functions

min_dev_size
Compute the minimum size to which device devid can be shrunk.