device_add

Function device_add 

pub fn device_add(fd: BorrowedFd<'_>, path: &CStr) -> Result<()>
Add a device to the btrfs filesystem referred to by fd.

path must be the path to an unmounted block device. The kernel requires CAP_SYS_ADMIN.