device_forget

Function device_forget 

pub fn device_forget(path: Option<&CStr>) -> Result<()>
Unregister a device (or all stale devices) from the kernel’s btrfs device scanner.

Opens /dev/btrfs-control and issues BTRFS_IOC_FORGET_DEV. If path is None, all devices that are not part of a currently mounted filesystem are unregistered. If path is Some, only that specific device path is unregistered.