device_info_all

Function device_info_all 

pub fn device_info_all(
    fd: BorrowedFd<'_>,
    fs_info: &FsInfo,
) -> Result<Vec<DevInfo>>
Query information about all devices in the filesystem referred to by fd, using the device count from a previously obtained FsInfo.

Iterates devids 1..=max_id, skipping any that return ENODEV (holes in the devid space are normal when devices have been removed).