Module features

Module features 

Feature flags: querying and setting filesystem feature flags

Wraps BTRFS_IOC_GET_FEATURES, BTRFS_IOC_GET_SUPPORTED_FEATURES, and BTRFS_IOC_SET_FEATURES to query and modify the feature flags of a mounted btrfs filesystem.

Structs

CompatRoFlags
Compatible read-only feature flags (compat_ro_flags).
FeatureFlags
The set of feature flags active on a mounted filesystem.
IncompatFlags
Incompatible feature flags (incompat_flags).
SupportedFeatures
The feature flags supported by the running kernel.

Functions

get_features
Query the feature flags currently active on the filesystem.
get_supported_features
Query the feature flags supported by the running kernel.
set_features
Set or clear feature flags on the filesystem.