pub fn get_features(fd: BorrowedFd<'_>) -> Result<FeatureFlags>Expand description
Query the feature flags currently active on the filesystem.
Errors
Returns Err if the ioctl fails.
pub fn get_features(fd: BorrowedFd<'_>) -> Result<FeatureFlags>Query the feature flags currently active on the filesystem.
Returns Err if the ioctl fails.