pub fn get_supported_features(fd: BorrowedFd<'_>) -> Result<SupportedFeatures>Expand description
Query the feature flags supported by the running kernel.
Returns three sets per category (compat_ro, incompat): which flags the kernel understands, which can be enabled at runtime, and which can be disabled at runtime.