pub fn filesystem_info(fd: BorrowedFd<'_>) -> Result<FilesystemInfo>Expand description
Query information about the btrfs filesystem referred to by fd.
pub fn filesystem_info(fd: BorrowedFd<'_>) -> Result<FilesystemInfo>Query information about the btrfs filesystem referred to by fd.