pub struct InoLookupUserResult {
pub name: String,
pub path: String,
}Expand description
Result of an unprivileged inode lookup (BTRFS_IOC_INO_LOOKUP_USER).
Contains the subvolume name and the path from the fd’s subvolume root to the directory containing the subvolume.
Fields
name: StringName of the subvolume.
path: StringPath from the fd’s subvolume root to the directory containing the
subvolume entry (dirid). Empty if the subvolume sits directly
under the subvolume root.