Module receive

Module receive 

Receive support: ioctls for applying a send stream to a filesystem

Provides safe wrappers for the kernel interfaces used when receiving a btrfs send stream: marking a subvolume as received (SET_RECEIVED_SUBVOL), cloning extents between files (CLONE_RANGE), and searching the UUID tree to locate subvolumes by their UUID or received UUID.

Structs

SubvolSearchResult
Result of searching the UUID tree for a subvolume.

Functions

clone_range
Clone a range of bytes from one file to another using BTRFS_IOC_CLONE_RANGE.
encoded_write
Write pre-compressed data to a file using BTRFS_IOC_ENCODED_WRITE.
received_subvol_set
Mark a subvolume as received by setting its received UUID and stransid.
subvolume_search_by_received_uuid
Search the UUID tree for a subvolume by its received UUID.
subvolume_search_by_uuid
Search the UUID tree for a subvolume by its UUID.