clone_range

Function clone_range 

pub fn clone_range(
    dest_fd: BorrowedFd<'_>,
    src_fd: BorrowedFd<'_>,
    src_offset: u64,
    src_length: u64,
    dest_offset: u64,
) -> Result<()>
Clone a range of bytes from one file to another using BTRFS_IOC_CLONE_RANGE.

Both files must be on the same btrfs filesystem. The destination file descriptor dest_fd is the ioctl target.