pub fn replace_status(fd: BorrowedFd<'_>) -> Result<ReplaceStatus>Expand description
Query the status of a device replace operation on the filesystem referred
to by fd.
pub fn replace_status(fd: BorrowedFd<'_>) -> Result<ReplaceStatus>Query the status of a device replace operation on the filesystem referred
to by fd.