pub struct ReplaceStatus {
pub state: ReplaceState,
pub progress_1000: u64,
pub time_started: Option<SystemTime>,
pub time_stopped: Option<SystemTime>,
pub num_write_errors: u64,
pub num_uncorrectable_read_errors: u64,
}Expand description
Status of a device replace operation, as returned by the status query.
Fields
state: ReplaceStateCurrent state of the replace operation.
progress_1000: u64Progress in tenths of a percent (0..=1000).
time_started: Option<SystemTime>Time the replace operation was started.
time_stopped: Option<SystemTime>Time the replace operation stopped (finished, canceled, or suspended).
num_write_errors: u64Number of write errors encountered during the replace.
num_uncorrectable_read_errors: u64Number of uncorrectable read errors encountered during the replace.