ResizeAmount

Enum ResizeAmount 

pub enum ResizeAmount {
    Cancel,
    Max,
    Set(u64),
    Add(u64),
    Sub(u64),
}
The target size for a resize operation.

Variants



Cancel

Cancel an in-progress resize.



Max

Grow the device to its maximum available size.



Set(u64)

Set the device to exactly this many bytes.



Add(u64)

Add this many bytes to the current device size.



Sub(u64)

Subtract this many bytes from the current device size.