pub fn scrub_progress(
fd: BorrowedFd<'_>,
devid: u64,
) -> Result<Option<ScrubProgress>>Expand description
Query the progress of the scrub currently running on the device identified
by devid within the filesystem referred to by fd.
Returns None if no scrub is running on that device (ENOTCONN).