Send stream: generating an incremental or full send stream from a subvolume
The kernel generates a binary stream representing the contents of a read-only
subvolume (or the delta between a parent and child snapshot). The stream is
written to a pipe; the caller reads from the other end and writes it to a
file or stdout for later consumption by btrfs receive.
Structs
- Send
Flags - Flags for the send ioctl.
Functions
- send
- Invoke
BTRFS_IOC_SENDon the given subvolume.