pub struct BlockGroupFlags(/* private fields */);Expand description
Block group / chunk type flags: the combination of chunk type (DATA, SYSTEM, METADATA) and RAID profile stored in on-disk chunk items and block group items.
Display produces the dump-tree format: DATA|DUP, METADATA|single, etc.
Implementations
Sourceimpl BlockGroupFlags
impl BlockGroupFlags
pub const DATA: BlockGroupFlags
pub const SYSTEM: BlockGroupFlags
pub const METADATA: BlockGroupFlags
pub const RAID0: BlockGroupFlags
pub const RAID1: BlockGroupFlags
pub const DUP: BlockGroupFlags
pub const RAID10: BlockGroupFlags
pub const RAID5: BlockGroupFlags
pub const RAID6: BlockGroupFlags
pub const RAID1C3: BlockGroupFlags
pub const RAID1C4: BlockGroupFlags
Sourcepub const SINGLE: BlockGroupFlags
pub const SINGLE: BlockGroupFlags
Explicit “single” marker (bit 48). When no profile bits are set, the allocation is also single.
Sourcepub const GLOBAL_RSV: BlockGroupFlags
pub const GLOBAL_RSV: BlockGroupFlags
Pseudo-type used for the global reservation pool.
Sourceimpl BlockGroupFlags
impl BlockGroupFlags
Sourcepub const fn empty() -> BlockGroupFlags
pub const fn empty() -> BlockGroupFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> BlockGroupFlags
pub const fn all() -> BlockGroupFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<BlockGroupFlags>
pub const fn from_bits(bits: u64) -> Option<BlockGroupFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> BlockGroupFlags
pub const fn from_bits_truncate(bits: u64) -> BlockGroupFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> BlockGroupFlags
pub const fn from_bits_retain(bits: u64) -> BlockGroupFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<BlockGroupFlags>
pub fn from_name(name: &str) -> Option<BlockGroupFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: BlockGroupFlags) -> bool
pub const fn intersects(&self, other: BlockGroupFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: BlockGroupFlags) -> bool
pub const fn contains(&self, other: BlockGroupFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: BlockGroupFlags)
pub fn insert(&mut self, other: BlockGroupFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: BlockGroupFlags)
pub fn remove(&mut self, other: BlockGroupFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: BlockGroupFlags)
pub fn toggle(&mut self, other: BlockGroupFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: BlockGroupFlags, value: bool)
pub fn set(&mut self, other: BlockGroupFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: BlockGroupFlags) -> BlockGroupFlags
pub const fn intersection(self, other: BlockGroupFlags) -> BlockGroupFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: BlockGroupFlags) -> BlockGroupFlags
pub const fn union(self, other: BlockGroupFlags) -> BlockGroupFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: BlockGroupFlags) -> BlockGroupFlags
pub const fn difference(self, other: BlockGroupFlags) -> BlockGroupFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: BlockGroupFlags,
) -> BlockGroupFlags
pub const fn symmetric_difference( self, other: BlockGroupFlags, ) -> BlockGroupFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> BlockGroupFlags
pub const fn complement(self) -> BlockGroupFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl BlockGroupFlags
impl BlockGroupFlags
Sourcepub const fn iter(&self) -> Iter<BlockGroupFlags>
pub const fn iter(&self) -> Iter<BlockGroupFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<BlockGroupFlags>
pub const fn iter_names(&self) -> IterNames<BlockGroupFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.