pub fn subvolume_flags_get(fd: BorrowedFd<'_>) -> Result<SubvolumeFlags>Expand description
Read the flags of the subvolume that fd belongs to.
pub fn subvolume_flags_get(fd: BorrowedFd<'_>) -> Result<SubvolumeFlags>Read the flags of the subvolume that fd belongs to.