pub fn sync(fd: BorrowedFd<'_>) -> Result<()>Expand description
Force a sync on the btrfs filesystem referred to by fd.
Equivalent to ioctl(fd, BTRFS_IOC_SYNC).
pub fn sync(fd: BorrowedFd<'_>) -> Result<()>Force a sync on the btrfs filesystem referred to by fd.
Equivalent to ioctl(fd, BTRFS_IOC_SYNC).