sysfs_btrfs_path_file

Function sysfs_btrfs_path_file 

pub fn sysfs_btrfs_path_file(uuid: &Uuid, name: &str) -> PathBuf
Returns the path to a named file within the sysfs directory for the filesystem with the given UUID: /sys/fs/btrfs/<uuid>/<name>.