pub struct SearchHeader {
pub transid: u64,
pub objectid: u64,
pub offset: u64,
pub item_type: u32,
pub len: u32,
}Expand description
Metadata returned for each item found by tree_search.
The header fields are in host byte order (the kernel fills them in through
the ioctl layer). The accompanying data slice passed to the callback is
the raw on-disk item payload and is in little-endian byte order.
Fields
transid: u64objectid: u64offset: u64item_type: u32Item type (the type field of the btrfs key).
len: u32Length in bytes of the item’s data payload.