pub struct BalanceArgs { /* private fields */ }Expand description
Per-type filter arguments for a balance operation, corresponding to
btrfs_balance_args.
Construct one with BalanceArgs::new and chain the setter methods to
enable filters. Each setter automatically sets the corresponding flag bit.
Implementations
Sourceimpl BalanceArgs
impl BalanceArgs
Sourcepub fn profiles(self, profiles: u64) -> Self
pub fn profiles(self, profiles: u64) -> Self
Filter by chunk profile bitmask. The value is a bitmask of
BTRFS_BLOCK_GROUP_* profile flags.
Sourcepub fn usage_range(self, min: u32, max: u32) -> Self
pub fn usage_range(self, min: u32, max: u32) -> Self
Filter chunks whose usage falls in min..=max percent.
Sourcepub fn drange(self, start: u64, end: u64) -> Self
pub fn drange(self, start: u64, end: u64) -> Self
Filter chunks whose physical range on-disk overlaps start..end.
Sourcepub fn vrange(self, start: u64, end: u64) -> Self
pub fn vrange(self, start: u64, end: u64) -> Self
Filter chunks whose virtual address range overlaps start..end.
Sourcepub fn limit_range(self, min: u32, max: u32) -> Self
pub fn limit_range(self, min: u32, max: u32) -> Self
Process between min and max chunks.
Sourcepub fn stripes_range(self, min: u32, max: u32) -> Self
pub fn stripes_range(self, min: u32, max: u32) -> Self
Filter chunks that span between min and max stripes.