Extent deduplication: comparing and deduplicating file extents
Wraps BTRFS_IOC_FILE_EXTENT_SAME to request that the kernel compare a
byte range in a source file against ranges in one or more destination files.
Where the data is identical, the destination extents are replaced with
references to the source extent, saving space.
Structs
- Dedupe
Target - A destination file and offset to deduplicate against the source range.
Enums
- Dedupe
Result - Result of a single dedupe comparison against one destination.
Functions
- file_
extent_ same - Deduplicate a source range against one or more destination ranges.