device_stats

Function device_stats 

pub fn device_stats(
    fd: BorrowedFd<'_>,
    devid: u64,
    reset: bool,
) -> Result<DevStats>
Query I/O error statistics for the device identified by devid within the filesystem referred to by fd.

If reset is true, the kernel atomically returns the current values and then resets all counters to zero. The kernel requires CAP_SYS_ADMIN.