Feature flags: querying and setting filesystem feature flags
Wraps BTRFS_IOC_GET_FEATURES, BTRFS_IOC_GET_SUPPORTED_FEATURES,
and BTRFS_IOC_SET_FEATURES to query and modify the feature flags of
a mounted btrfs filesystem.
Structs
- Compat
RoFlags - Compatible read-only feature flags (
compat_ro_flags). - Feature
Flags - The set of feature flags active on a mounted filesystem.
- Incompat
Flags - Incompatible feature flags (
incompat_flags). - Supported
Features - The feature flags supported by the running kernel.
Functions
- get_
features - Query the feature flags currently active on the filesystem.
- get_
supported_ features - Query the feature flags supported by the running kernel.
- set_
features - Set or clear feature flags on the filesystem.