pub fn get_features(fd: BorrowedFd<'_>) -> Result<FeatureFlags>Expand description
Query the feature flags currently active on the filesystem.
pub fn get_features(fd: BorrowedFd<'_>) -> Result<FeatureFlags>Query the feature flags currently active on the filesystem.