pub fn start_sync(fd: BorrowedFd<'_>) -> Result<u64>Expand description
Asynchronously start a sync on the btrfs filesystem referred to by fd.
Returns the transaction ID of the initiated sync, which can be passed to
wait_sync to block until it completes.