pub fn sync(fd: BorrowedFd<'_>) -> Result<()>Expand description
Force a sync on the btrfs filesystem referred to by fd and wait for it
to complete.
pub fn sync(fd: BorrowedFd<'_>) -> Result<()>Force a sync on the btrfs filesystem referred to by fd and wait for it
to complete.