Receive support: ioctls for applying a send stream to a filesystem
Provides safe wrappers for the kernel interfaces used when receiving a btrfs
send stream: marking a subvolume as received (SET_RECEIVED_SUBVOL), cloning
extents between files (CLONE_RANGE), and searching the UUID tree to locate
subvolumes by their UUID or received UUID.
Structs
- Subvol
Search Result - Result of searching the UUID tree for a subvolume.
Functions
- clone_
range - Clone a range of bytes from one file to another using
BTRFS_IOC_CLONE_RANGE. - encoded_
write - Write pre-compressed data to a file using
BTRFS_IOC_ENCODED_WRITE. - received_
subvol_ set - Mark a subvolume as received by setting its received UUID and stransid.
- subvolume_
search_ by_ received_ uuid - Search the UUID tree for a subvolume by its received UUID.
- subvolume_
search_ by_ uuid - Search the UUID tree for a subvolume by its UUID.