ReplaceStartError

Enum ReplaceStartError 

pub enum ReplaceStartError {
    AlreadyStarted,
    ScrubInProgress,
}
Result of a replace start attempt that the kernel rejected at the application level (ioctl succeeded but the result field indicates a problem).

Variants



AlreadyStarted

A replace operation is already in progress.



ScrubInProgress

A scrub is in progress and must finish before replace can start.