pub fn replace_status(fd: BorrowedFd<'_>) -> Result<ReplaceStatus>Expand description
Query the status of a device replace operation on the filesystem referred
to by fd.
Errors
Returns Err if the ioctl fails.
pub fn replace_status(fd: BorrowedFd<'_>) -> Result<ReplaceStatus>Query the status of a device replace operation on the filesystem referred
to by fd.
Returns Err if the ioctl fails.