pub fn resize(fd: BorrowedFd<'_>, args: ResizeArgs) -> Result<()>Expand description
Resize a device within the btrfs filesystem referred to by fd.
fd must be an open file descriptor to a directory on the mounted
filesystem. Use ResizeArgs to specify the target device and amount.