Block group space usage: how much space each chunk type allocates and uses
Reports the allocated and used byte counts for each combination of block
group type (data, metadata, system) and RAID profile. This is the data
underlying the btrfs filesystem df command.
Structs
- Block
Group Flags - Block group / chunk type flags: the combination of chunk type (DATA, SYSTEM, METADATA) and RAID profile stored in on-disk chunk items and block group items.
- Space
Info - Space usage information for one block group type/profile combination.
Functions
- space_
info - Query space usage by block group type for the filesystem referred to by
fd.