pub fn space_info(fd: BorrowedFd<'_>) -> Result<Vec<SpaceInfo>>Expand description
Query space usage by block group type for the filesystem referred to by
fd.
Returns one SpaceInfo entry per block group type/profile combination.
Uses a two-phase ioctl call: the first call with space_slots = 0
retrieves the entry count, and the second call retrieves all entries.