pub fn subvol_sync_wait_all(fd: BorrowedFd<'_>) -> Result<()>Expand description
Wait for all currently queued subvolume deletions to complete.
Blocks until every subvolume that was in the deletion queue at the time of the call has been fully cleaned. Does not wait for subvolumes deleted after the call is made.
Errors
Returns Err if the ioctl fails.