CommitStats

Struct CommitStats 

pub struct CommitStats {
    pub commits: u64,
    pub cur_commit_ms: u64,
    pub last_commit_ms: u64,
    pub max_commit_ms: u64,
    pub total_commit_ms: u64,
}
Commit statistics for a mounted btrfs filesystem, read from /sys/fs/btrfs/<uuid>/commit_stats.

Fields

commits: u64

Total number of commits since mount.

cur_commit_ms: u64

Duration of the current (in-progress) commit in milliseconds.

last_commit_ms: u64

Duration of the last completed commit in milliseconds.

max_commit_ms: u64

Maximum commit duration since mount (or last reset) in milliseconds.

total_commit_ms: u64

Total time spent in commits since mount in milliseconds.